Task: WikiQA
=============
Description: Open domain QA from Wikipedia dataset from Yang et al. '15. 

Link: https://www.microsoft.com/en-us/research/publication/wikiqa-a-challenge-dataset-for-open-domain-question-answering/

Tags: #WikiQA, #All, #QA

